from distutils.core import setup
setup(
	name = 'nesterffff',
	version = '1.0.0',
	py_modules = ['nesterffff'],
	author = 'scl',
	author_email = 'ak@ak.com',
	url = 'http://bbs.sinounix.com',
	description = 'a test file',
)
